local E, L, V, P, G = unpack(ElvUI);
local M = E:GetModule('MaUI');

--Cache global variables
--Lua functions
local _G = _G
local unpack = unpack
local format = format
--WoW API / Variables
local CreateFrame = CreateFrame
local IsAddOnLoaded = IsAddOnLoaded
local GetScreenWidth = GetScreenWidth
local SetCVar = SetCVar
local PlaySoundFile = PlaySoundFile
local ReloadUI = ReloadUI
local UIFrameFadeOut = UIFrameFadeOut
local ChatFrame_AddMessageGroup = ChatFrame_AddMessageGroup
local ChatFrame_RemoveAllMessageGroups = ChatFrame_RemoveAllMessageGroups
local ChatFrame_AddChannel = ChatFrame_AddChannel
local ChatFrame_RemoveChannel = ChatFrame_RemoveChannel
local ChangeChatColor = ChangeChatColor
local ToggleChatColorNamesByClassGroup = ToggleChatColorNamesByClassGroup
local FCF_ResetChatWindows = FCF_ResetChatWindows
local FCF_SetLocked = FCF_SetLocked
local FCF_DockFrame, FCF_UnDockFrame = FCF_DockFrame, FCF_UnDockFrame
local FCF_OpenNewWindow = FCF_OpenNewWindow
local FCF_SavePositionAndDimensions = FCF_SavePositionAndDimensions
local FCF_GetChatWindowInfo = FCF_GetChatWindowInfo
local FCF_SetWindowName = FCF_SetWindowName
local FCF_StopDragging = FCF_StopDragging
local FCF_SetChatWindowFontSize = FCF_SetChatWindowFontSize
local CLASS, CONTINUE, PREVIOUS = CLASS, CONTINUE, PREVIOUS
local NUM_CHAT_WINDOWS = NUM_CHAT_WINDOWS
local LOOT, GENERAL, TRADE = LOOT, GENERAL, TRADE
local GUILD_EVENT_LOG = GUILD_EVENT_LOG
local RAID_CLASS_COLORS = RAID_CLASS_COLORS
local CUSTOM_CLASS_COLORS = CUSTOM_CLASS_COLORS

local CURRENT_PAGE = 0
local MAX_PAGE = 6

local function MaUISetupChat()
	-- Chat
	E.db["chat"]["tabFontOutline"] = "OUTLINE"
	E.db["chat"]["keywordSound"] = "Whisper Alert"
	E.db["chat"]["tabFont"] = "MaUI Kait"
	E.db["chat"]["panelWidth"] = 420
	E.db["chat"]["keywords"] = "%MYNAME%"
	E.db["chat"]["timeStampFormat"] = "%H:%M "
	E.db["chat"]["panelHeight"] = 150
	
	E:UpdateAll(true)
end

local function MaUISetupActionbars()
	--Actionbars
	E.db["actionbar"]["bar3"]["buttonspacing"] = 4
	E.db["actionbar"]["bar3"]["buttons"] = 12
	E.db["actionbar"]["bar3"]["backdrop"] = true
	E.db["actionbar"]["bar2"]["buttonspacing"] = 4
	E.db["actionbar"]["bar2"]["enabled"] = true
	E.db["actionbar"]["bar1"]["buttonspacing"] = 4
	E.db["actionbar"]["bar1"]["heightMult"] = 2
	E.db["actionbar"]["bar1"]["backdrop"] = true
	E.db["actionbar"]["bar5"]["buttonspacing"] = 4
	E.db["actionbar"]["bar5"]["buttons"] = 12
	E.db["actionbar"]["bar5"]["backdrop"] = true
	E.db["actionbar"]["extraActionButton"]["scale"] = 0.8
	E.db["actionbar"]["extraActionButton"]["alpha"] = 0.8
	E.db["actionbar"]["backdropSpacingConverted"] = true
	E.db["actionbar"]["macrotext"] = true
	E.db["actionbar"]["stanceBar"]["backdrop"] = true
	E.db["actionbar"]["stanceBar"]["buttonsize"] = 24
	E.db["actionbar"]["barPet"]["mouseover"] = true
	E.db["actionbar"]["barPet"]["buttonsPerRow"] = 10
	E.db["actionbar"]["barPet"]["buttonsize"] = 18
	E.db["actionbar"]["bar4"]["enabled"] = false
	
	E:UpdateAll(true)
end

local function MaUISetupLayout()
	--Datatexts
	do
		E.db["datatexts"]["time24"] = true
		E.db["datatexts"]["panels"]["LeftMiniPanel"] = "Berufe"
		E.db["datatexts"]["panels"]["RightChatDataPanel"]["middle"] = "Menu"
		E.db["datatexts"]["panels"]["LeftChatDataPanel"]["right"] = "Friends"
		E.db["datatexts"]["panels"]["LeftChatDataPanel"]["left"] = "Guild"
		E.db["datatexts"]["panels"]["RightMiniPanel"] = "Time"
		E.db["datatexts"]["goldCoins"] = true
	end
	
	--Unitframes
	do
		E.db["unitframe"]["statusbar"] = "MaUI Fer 1"
				
		--Pet
		E.db["unitframe"]["units"]["pet"]["threatStyle"] = "HEALTHBORDER"
		E.db["unitframe"]["units"]["pet"]["castbar"]["enable"] = false
		E.db["unitframe"]["units"]["pet"]["castbar"]["width"] = 110
		E.db["unitframe"]["units"]["pet"]["width"] = 110
		E.db["unitframe"]["units"]["pet"]["power"]["enable"] = false
		E.db["unitframe"]["units"]["pet"]["height"] = 24
						
		--TargetTarget
		E.db["unitframe"]["units"]["targettarget"]["debuffs"]["yOffset"] = 2
		E.db["unitframe"]["units"]["targettarget"]["debuffs"]["anchorPoint"] = "TOPRIGHT"
		E.db["unitframe"]["units"]["targettarget"]["debuffs"]["perrow"] = 4
		E.db["unitframe"]["units"]["targettarget"]["threatStyle"] = "HEALTHBORDER"
		E.db["unitframe"]["units"]["targettarget"]["power"]["enable"] = false
		E.db["unitframe"]["units"]["targettarget"]["height"] = 24
		E.db["unitframe"]["units"]["targettarget"]["buffs"]["yOffset"] = 2
		E.db["unitframe"]["units"]["targettarget"]["buffs"]["anchorPoint"] = "BOTTOMRIGHT"
		E.db["unitframe"]["units"]["targettarget"]["buffs"]["perrow"] = 9
		E.db["unitframe"]["units"]["targettarget"]["raidicon"]["attachTo"] = "LEFT"
		E.db["unitframe"]["units"]["targettarget"]["raidicon"]["yOffset"] = 0
		
		--Arena
		E.db["unitframe"]["units"]["arena"]["debuffs"]["yOffset"] = 2
		E.db["unitframe"]["units"]["arena"]["debuffs"]["anchorPoint"] = "TOPRIGHT"
		E.db["unitframe"]["units"]["arena"]["debuffs"]["sizeOverride"] = 24
		E.db["unitframe"]["units"]["arena"]["spacing"] = 44
		E.db["unitframe"]["units"]["arena"]["power"]["width"] = "spaced"
		E.db["unitframe"]["units"]["arena"]["width"] = 200
		E.db["unitframe"]["units"]["arena"]["orientation"] = "LEFT"
		E.db["unitframe"]["units"]["arena"]["buffs"]["yOffset"] = 2
		E.db["unitframe"]["units"]["arena"]["buffs"]["anchorPoint"] = "TOPLEFT"
		E.db["unitframe"]["units"]["arena"]["buffs"]["sizeOverride"] = 24
		E.db["unitframe"]["units"]["arena"]["castbar"]["width"] = 200
		E.db["unitframe"]["units"]["arena"]["castbar"]["height"] = 10
		E.db["unitframe"]["units"]["arena"]["height"] = 28
		
		--Party
		E.db["unitframe"]["units"]["party"]["debuffs"]["sizeOverride"] = 16
		E.db["unitframe"]["units"]["party"]["debuffs"]["yOffset"] = -7
		E.db["unitframe"]["units"]["party"]["debuffs"]["anchorPoint"] = "TOPRIGHT"
		E.db["unitframe"]["units"]["party"]["debuffs"]["xOffset"] = -4
		E.db["unitframe"]["units"]["party"]["threatStyle"] = "HEALTHBORDER"
		E.db["unitframe"]["units"]["party"]["GPSArrow"]["size"] = 40
		E.db["unitframe"]["units"]["party"]["healPrediction"] = true
		E.db["unitframe"]["units"]["party"]["name"]["xOffset"] = 4
		E.db["unitframe"]["units"]["party"]["name"]["text_format"] = "[namecolor][name:short]"
		E.db["unitframe"]["units"]["party"]["height"] = 35
		E.db["unitframe"]["units"]["party"]["buffs"]["xOffset"] = 24
		E.db["unitframe"]["units"]["party"]["buffs"]["yOffset"] = 2
		E.db["unitframe"]["units"]["party"]["buffs"]["clickThrough"] = true
		E.db["unitframe"]["units"]["party"]["buffs"]["useBlacklist"] = false
		E.db["unitframe"]["units"]["party"]["buffs"]["noDuration"] = false
		E.db["unitframe"]["units"]["party"]["buffs"]["playerOnly"] = false
		E.db["unitframe"]["units"]["party"]["buffs"]["perrow"] = 1
		E.db["unitframe"]["units"]["party"]["buffs"]["useFilter"] = "TurtleBuffs"
		E.db["unitframe"]["units"]["party"]["buffs"]["noConsolidated"] = false
		E.db["unitframe"]["units"]["party"]["buffs"]["sizeOverride"] = 22
		E.db["unitframe"]["units"]["party"]["buffs"]["enable"] = true
		E.db["unitframe"]["units"]["party"]["raidicon"]["attachTo"] = "TOPLEFT"
		E.db["unitframe"]["units"]["party"]["raidicon"]["xOffset"] = -2
		E.db["unitframe"]["units"]["party"]["raidicon"]["yOffset"] = 14
		E.db["unitframe"]["units"]["party"]["horizontalSpacing"] = 5
		E.db["unitframe"]["units"]["party"]["growthDirection"] = "LEFT_UP"
		E.db["unitframe"]["units"]["party"]["roleIcon"]["position"] = "BOTTOMRIGHT"
		E.db["unitframe"]["units"]["party"]["power"]["text_format"] = ""
		E.db["unitframe"]["units"]["party"]["width"] = 80
		E.db["unitframe"]["units"]["party"]["health"]["frequentUpdates"] = true
		E.db["unitframe"]["units"]["party"]["health"]["position"] = "BOTTOM"
		E.db["unitframe"]["units"]["party"]["health"]["text_format"] = ""
		E.db["unitframe"]["units"]["party"]["verticalSpacing"] = 11
		
		--Raid 40			
		E.db["unitframe"]["units"]["raid40"]["horizontalSpacing"] = 5
		E.db["unitframe"]["units"]["raid40"]["growthDirection"] = "LEFT_UP"
		E.db["unitframe"]["units"]["raid40"]["orientation"] = "LEFT"
		E.db["unitframe"]["units"]["raid40"]["roleIcon"]["enable"] = true
		E.db["unitframe"]["units"]["raid40"]["threatStyle"] = "HEALTHBORDER"
		E.db["unitframe"]["units"]["raid40"]["GPSArrow"]["enable"] = true
		E.db["unitframe"]["units"]["raid40"]["healPrediction"] = true
		E.db["unitframe"]["units"]["raid40"]["health"]["frequentUpdates"] = true
		E.db["unitframe"]["units"]["raid40"]["height"] = 30
		E.db["unitframe"]["units"]["raid40"]["raidicon"]["attachTo"] = "TOPLEFT"
		E.db["unitframe"]["units"]["raid40"]["raidicon"]["xOffset"] = -2
		E.db["unitframe"]["units"]["raid40"]["raidicon"]["yOffset"] = 14
		
		--Focus
		E.db["unitframe"]["units"]["focus"]["debuffs"]["yOffset"] = 2
		E.db["unitframe"]["units"]["focus"]["GPSArrow"]["enable"] = true
		E.db["unitframe"]["units"]["focus"]["threatStyle"] = "HEALTHBORDER"
		E.db["unitframe"]["units"]["focus"]["castbar"]["width"] = 110
		E.db["unitframe"]["units"]["focus"]["power"]["enable"] = false
		E.db["unitframe"]["units"]["focus"]["width"] = 110
		E.db["unitframe"]["units"]["focus"]["height"] = 24
		
		--Target
		E.db["unitframe"]["units"]["target"]["debuffs"]["sizeOverride"] = 0
		E.db["unitframe"]["units"]["target"]["debuffs"]["yOffset"] = 2
		E.db["unitframe"]["units"]["target"]["debuffs"]["anchorPoint"] = "TOPLEFT"
		E.db["unitframe"]["units"]["target"]["debuffs"]["perrow"] = 10
		E.db["unitframe"]["units"]["target"]["smartAuraDisplay"] = "DISABLED"
		E.db["unitframe"]["units"]["target"]["aurabar"]["enable"] = false
		E.db["unitframe"]["units"]["target"]["threatStyle"] = "HEALTHBORDER"
		E.db["unitframe"]["units"]["target"]["GPSArrow"]["enable"] = true
		E.db["unitframe"]["units"]["target"]["width"] = 220
		E.db["unitframe"]["units"]["target"]["name"]["position"] = "RIGHT"
		E.db["unitframe"]["units"]["target"]["name"]["text_format"] = "[healthcolor][health:current-percent] [namecolor][name:medium] [difficultycolor][smartlevel] [shortclassification]"
		E.db["unitframe"]["units"]["target"]["health"]["xOffset"] = -40
		E.db["unitframe"]["units"]["target"]["health"]["text_format"] = ""
		E.db["unitframe"]["units"]["target"]["power"]["detachFromFrame"] = true
		E.db["unitframe"]["units"]["target"]["power"]["height"] = 18
		E.db["unitframe"]["units"]["target"]["power"]["hideonnpc"] = false
		E.db["unitframe"]["units"]["target"]["power"]["detachedWidth"] = 220
		E.db["unitframe"]["units"]["target"]["height"] = 24
		E.db["unitframe"]["units"]["target"]["buffs"]["sizeOverride"] = 0
		E.db["unitframe"]["units"]["target"]["buffs"]["yOffset"] = 2
		E.db["unitframe"]["units"]["target"]["buffs"]["anchorPoint"] = "TOPLEFT"
		E.db["unitframe"]["units"]["target"]["buffs"]["perrow"] = 10
		E.db["unitframe"]["units"]["target"]["castbar"]["width"] = 434
		E.db["unitframe"]["units"]["target"]["castbar"]["latency"] = false
		E.db["unitframe"]["units"]["target"]["raidicon"]["yOffset"] = -14
		E.db["unitframe"]["units"]["target"]["customTexts"] = {
							["Classe"] = {
								["attachTextTo"] = "HEALTH",
								["font"] = "PT Sans Narrow",
								["justifyH"] = "RIGHT",
								["fontOutline"] = "OUTLINE",
								["xOffset"] = 0,
								["yOffset"] = -45,
								["text_format"] = "[MaRassColor][MaClassification]",
								["size"] = 20,
							},
							["Prozent"] = {
								["attachTextTo"] = "HEALTH",
								["font"] = "PT Sans Narrow",
								["justifyH"] = "LEFT",
								["fontOutline"] = "OUTLINE",
								["xOffset"] = 0,
								["yOffset"] = -45,
								["text_format"] = "[namecolor][health:percent]",
								["size"] = 20,
							},
						}
		
		--Raid
		E.db["unitframe"]["units"]["raid"]["horizontalSpacing"] = 5
		E.db["unitframe"]["units"]["raid"]["debuffs"]["sizeOverride"] = 16
		E.db["unitframe"]["units"]["raid"]["debuffs"]["enable"] = true
		E.db["unitframe"]["units"]["raid"]["debuffs"]["yOffset"] = -7
		E.db["unitframe"]["units"]["raid"]["debuffs"]["anchorPoint"] = "TOPRIGHT"
		E.db["unitframe"]["units"]["raid"]["debuffs"]["xOffset"] = -4
		E.db["unitframe"]["units"]["raid"]["height"] = 35
		E.db["unitframe"]["units"]["raid"]["rdebuffs"]["enable"] = false
		E.db["unitframe"]["units"]["raid"]["growthDirection"] = "LEFT_UP"
		E.db["unitframe"]["units"]["raid"]["threatStyle"] = "HEALTHBORDER"
		E.db["unitframe"]["units"]["raid"]["power"]["power"] = false
		E.db["unitframe"]["units"]["raid"]["positionOverride"] = "BOTTOMRIGHT"
		E.db["unitframe"]["units"]["raid"]["healPrediction"] = true
		E.db["unitframe"]["units"]["raid"]["verticalSpacing"] = 11
		E.db["unitframe"]["units"]["raid"]["name"]["xOffset"] = 4
		E.db["unitframe"]["units"]["raid"]["health"]["frequentUpdates"] = true
		E.db["unitframe"]["units"]["raid"]["health"]["text_format"] = ""
		E.db["unitframe"]["units"]["raid"]["orientation"] = "LEFT"
		E.db["unitframe"]["units"]["raid"]["buffs"]["xOffset"] = 24
		E.db["unitframe"]["units"]["raid"]["buffs"]["yOffset"] = 1
		E.db["unitframe"]["units"]["raid"]["buffs"]["clickThrough"] = true
		E.db["unitframe"]["units"]["raid"]["buffs"]["useBlacklist"] = false
		E.db["unitframe"]["units"]["raid"]["buffs"]["noDuration"] = false
		E.db["unitframe"]["units"]["raid"]["buffs"]["playerOnly"] = false
		E.db["unitframe"]["units"]["raid"]["buffs"]["perrow"] = 1
		E.db["unitframe"]["units"]["raid"]["buffs"]["useFilter"] = "TurtleBuffs"
		E.db["unitframe"]["units"]["raid"]["buffs"]["noConsolidated"] = false
		E.db["unitframe"]["units"]["raid"]["buffs"]["sizeOverride"] = 22
		E.db["unitframe"]["units"]["raid"]["buffs"]["enable"] = true
		E.db["unitframe"]["units"]["raid"]["raidicon"]["attachTo"] = "TOPLEFT"
		E.db["unitframe"]["units"]["raid"]["raidicon"]["xOffset"] = -2
		E.db["unitframe"]["units"]["raid"]["raidicon"]["yOffset"] = 14
		
		--Boss
		E.db["unitframe"]["units"]["boss"]["debuffs"]["sizeOverride"] = 24
		E.db["unitframe"]["units"]["boss"]["debuffs"]["yOffset"] = 2
		E.db["unitframe"]["units"]["boss"]["debuffs"]["anchorPoint"] = "TOPRIGHT"
		E.db["unitframe"]["units"]["boss"]["debuffs"]["numrows"] = 1
		E.db["unitframe"]["units"]["boss"]["portrait"]["camDistanceScale"] = 2
		E.db["unitframe"]["units"]["boss"]["portrait"]["width"] = 45
		E.db["unitframe"]["units"]["boss"]["spacing"] = 44
		E.db["unitframe"]["units"]["boss"]["threatStyle"] = "HEALTHBORDER"
		E.db["unitframe"]["units"]["boss"]["power"]["width"] = "spaced"
		E.db["unitframe"]["units"]["boss"]["orientation"] = "LEFT"
		E.db["unitframe"]["units"]["boss"]["width"] = 200
		E.db["unitframe"]["units"]["boss"]["infoPanel"]["height"] = 17
		E.db["unitframe"]["units"]["boss"]["castbar"]["width"] = 200
		E.db["unitframe"]["units"]["boss"]["castbar"]["height"] = 10
		E.db["unitframe"]["units"]["boss"]["height"] = 28
		E.db["unitframe"]["units"]["boss"]["buffs"]["yOffset"] = 2
		E.db["unitframe"]["units"]["boss"]["buffs"]["anchorPoint"] = "TOPLEFT"
		E.db["unitframe"]["units"]["boss"]["buffs"]["sizeOverride"] = 24
		
		--Player
		E.db["unitframe"]["units"]["player"]["debuffs"]["sizeOverride"] = 0
		E.db["unitframe"]["units"]["player"]["debuffs"]["yOffset"] = 2
		E.db["unitframe"]["units"]["player"]["debuffs"]["perrow"] = 10
		E.db["unitframe"]["units"]["player"]["debuffs"]["attachTo"] = "HEALTH"
		E.db["unitframe"]["units"]["player"]["classbar"]["detachFromFrame"] = true
		E.db["unitframe"]["units"]["player"]["classbar"]["detachedWidth"] = 220
		E.db["unitframe"]["units"]["player"]["classbar"]["fill"] = "spaced"
		E.db["unitframe"]["units"]["player"]["aurabar"]["enable"] = false
		E.db["unitframe"]["units"]["player"]["threatStyle"] = "HEALTHBORDER"
		E.db["unitframe"]["units"]["player"]["power"]["height"] = 18
		E.db["unitframe"]["units"]["player"]["power"]["detachFromFrame"] = true
		E.db["unitframe"]["units"]["player"]["power"]["detachedWidth"] = 220
		E.db["unitframe"]["units"]["player"]["width"] = 220
		E.db["unitframe"]["units"]["player"]["castbar"]["spark"] = false
		E.db["unitframe"]["units"]["player"]["castbar"]["width"] = 434
		E.db["unitframe"]["units"]["player"]["castbar"]["height"] = 12
		E.db["unitframe"]["units"]["player"]["height"] = 24
		E.db["unitframe"]["units"]["player"]["buffs"]["enable"] = false
		E.db["unitframe"]["units"]["player"]["raidicon"]["yOffset"] = -14
		E.db["unitframe"]["units"]["player"]["customTexts"] = {
							["Prozent"] = {
								["attachTextTo"] = "Frame",
								["font"] = "PT Sans Narrow",
								["justifyH"] = "RIGHT",
								["fontOutline"] = "OUTLINE",
								["xOffset"] = 0,
								["yOffset"] = -45,
								["text_format"] = "[namecolor][health:percent]",
								["size"] = 20,
							},
						}
		
		--Healthbar
		E.db["unitframe"]["smoothbars"] = true
				
		--Colors
		E.db["unitframe"]["colors"]["healthclass"] = true
		E.db["unitframe"]["colors"]["customhealthbackdrop"] = true
		
		--Health Backdrop
		E.db["unitframe"]["colors"]["health_backdrop"]["r"] = 0.0941176470588235
		E.db["unitframe"]["colors"]["health_backdrop"]["g"] = 0.0941176470588235
		E.db["unitframe"]["colors"]["health_backdrop"]["b"] = 0.0941176470588235
		
		--Castbar
		E.db["unitframe"]["colors"]["castClassColor"] = true
		E.db["unitframe"]["colors"]["castColor"]["r"] = 0.509803921568627
		E.db["unitframe"]["colors"]["castColor"]["g"] = 0.882352941176471
		E.db["unitframe"]["colors"]["castColor"]["b"] = 0.227450980392157	
	end
	
	--Nameplates
	do
		E.db["nameplates"]["fontSize"] = 12
		E.db["nameplates"]["nonTargetTransparency"] = 0.5
		E.db["nameplates"]["statusbar"] = "MaUI Fer 1"
		E.db["nameplates"]["motionType"] = "OVERLAP"
		E.db["nameplates"]["fontOutline"] = "OUTLINE"
		E.db["nameplates"]["threat"]["beingTankedByTankColor"]["b"] = 0.850980392156863
		E.db["nameplates"]["threat"]["beingTankedByTankColor"]["g"] = 0.72156862745098
		E.db["nameplates"]["threat"]["beingTankedByTankColor"]["r"] = 0.180392156862745
		E.db["nameplates"]["threat"]["badScale"] = 1.5
		E.db["nameplates"]["units"]["HEALER"]["showLevel"] = true
		E.db["nameplates"]["units"]["ENEMY_NPC"]["powerbar"]["height"] = 4
		E.db["nameplates"]["font"] = "PT Sans Narrow"
	end
	
	--General
	do
		E.db["general"]["totems"]["sortDirection"] = "DESCENDING"
		E.db["general"]["totems"]["size"] = 32
		E.db["general"]["hideTutorial"] = 1
		E.db["general"]["mapAlpha"] = 0.7
		E.db["general"]["bottomPanel"] = false
		E.db["general"]["objectiveFrameHeight"] = 630
		E.db["general"]["topPanel"] = false
		E.db["general"]["bonusObjectivePosition"] = "AUTO"
		E.db["general"]["vendorGrays"] = true
		E.db["general"]["autoRoll"] = true
		E.db["general"]["autoRepair"] = "PLAYER"
		E.db["general"]["minimap"]["locationText"] = "HIDE"
		E.db["general"]["minimap"]["icons"]["classHall"]["position"] = "LEFT"
		E.db["general"]["minimap"]["icons"]["classHall"]["scale"] = 0.5
		E.db["general"]["minimap"]["size"] = 150
	end
	
	--Tooltip
	E.db["tooltip"]["itemCount"] = "BOTH"
	
	--Bags
	do
		E.db["bags"]["bagSize"] = 30
		E.db["bags"]["bankSize"] = 30
		E.db["bags"]["moneyFormat"] = "SHORTINT"
		E.db["bags"]["junkIcon"] = true
	end
	
	--Auras
	do	
		E.db["bossAuraFiltersConverted"] = true
		E.db["auras"]["fadeThreshold"] = 10
		E.db["auras"]["buffs"]["horizontalSpacing"] = 2
		E.db["auras"]["buffs"]["wrapAfter"] = 18
		E.db["auras"]["buffs"]["size"] = 24
		E.db["auras"]["debuffs"]["horizontalSpacing"] = 2
		E.db["auras"]["debuffs"]["wrapAfter"] = 18
		E.db["auras"]["debuffs"]["size"] = 24
	end
	
	--Databars
	do
		E.db["databars"]["artifact"]["width"] = 420
		E.db["databars"]["artifact"]["orientation"] = "HORIZONTAL"
		E.db["databars"]["artifact"]["height"] = 6
		E.db["databars"]["reputation"]["enable"] = true
		E.db["databars"]["reputation"]["width"] = 420
		E.db["databars"]["reputation"]["height"] = 6
		E.db["databars"]["reputation"]["orientation"] = "HORIZONTAL"
		E.db["databars"]["experience"]["width"] = 420
		E.db["databars"]["experience"]["orientation"] = "HORIZONTAL"
		E.db["databars"]["experience"]["height"] = 6
		E.db["databars"]["honor"]["enable"] = false
	end
	
	--Global
	do
		E.private["general"]["normTex"] = "MaUI Fer 1"
		E.private["general"]["glossTex"] = "MaUI Fer 1"
	end
	
	--Movers
	do
		E.db["movers"]["ElvUF_FocusCastbarMover"] = "BOTTOM,ElvUIParent,BOTTOM,163,132"
		E.db["movers"]["MinimapButtonAnchor"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-181"
		E.db["movers"]["LeftChatMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,4,4"
		E.db["movers"]["GMMover"] = "TOPLEFT,ElvUIParent,TOPLEFT,4,-4"
		E.db["movers"]["BuffsMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-158,-4"
		E.db["movers"]["TargetPowerBarMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-514,131"
		E.db["movers"]["MirrorTimer3Mover"] = "TOP,ElvUIParent,TOP,0,-160"
		E.db["movers"]["BossButton"] = "BOTTOM,ElvUIParent,BOTTOM,0,185"
		E.db["movers"]["LootFrameMover"] = "TOPLEFT,ElvUIParent,TOPLEFT,4,-90"
		E.db["movers"]["ElvUF_raidMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,2,176"
		E.db["movers"]["DigSiteProgressBarMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,315"
		E.db["movers"]["ElvUF_RaidpetMover"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,4,736"
		E.db["movers"]["ElvUF_FocusMover"] = "BOTTOM,ElvUIParent,BOTTOM,163,151"
		E.db["movers"]["ClassBarMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,514,177"
		E.db["movers"]["VehicleSeatMover"] = "TOPLEFT,ElvUIParent,TOPLEFT,4,-120"
		E.db["movers"]["ExperienceBarMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-4,176"
		E.db["movers"]["ElvUF_AssistMover"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,2,688"
		E.db["movers"]["ElvUF_TargetMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-514,151"
		E.db["movers"]["ElvUF_TargetTargetMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,151"
		E.db["movers"]["ElvUF_RaidMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMLEFT,424,156"
		E.db["movers"]["ElvUF_Raid40Mover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMLEFT,424,156"
		E.db["movers"]["MirrorTimer1Mover"] = "TOP,ElvUIParent,TOP,0,-120"
		E.db["movers"]["ElvUF_PartyMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMLEFT,424,156"
		E.db["movers"]["ElvAB_1"] = "BOTTOM,ElvUIParent,BOTTOM,0,4"
		E.db["movers"]["ElvAB_2"] = "BOTTOM,ElvUIParent,BOTTOM,0,40"
		E.db["movers"]["TotemBarMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,427,4"
		E.db["movers"]["ElvUF_PlayerMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,514,151"
		E.db["movers"]["BossHeaderMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-382"
		E.db["movers"]["WatchFrameMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-122,-292"
		E.db["movers"]["AltPowerBarMover"] = "TOP,ElvUIParent,TOP,0,-66"
		E.db["movers"]["ElvAB_3"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-520,4"
		E.db["movers"]["ElvAB_5"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,520,4"
		E.db["movers"]["ArtifactBarMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-4,156"
		E.db["movers"]["ElvUF_PlayerCastbarMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,80"
		E.db["movers"]["ArenaHeaderMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-382"
		E.db["movers"]["ObjectiveFrameMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-116,-244"
		E.db["movers"]["MirrorTimer2Mover"] = "TOP,ElvUIParent,TOP,0,-140"
		E.db["movers"]["ShiftAB"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,520,108"
		E.db["movers"]["BNETMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-181"
		E.db["movers"]["PlayerPowerBarMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,514,131"
		E.db["movers"]["ElvUF_TargetCastbarMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,94"
		E.db["movers"]["ReputationBarMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-4,166"
		E.db["movers"]["ElvUF_TankMover"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,2,788"
		E.db["movers"]["tokenHolderMover"] = "TOPLEFT,ElvUIParent,TOPLEFT,3,-110"
		E.db["movers"]["ElvUF_PetMover"] = "BOTTOM,ElvUIParent,BOTTOM,-163,151"
		E.db["movers"]["PetAB"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,520,80"
		E.db["movers"]["RightChatMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-4,4"
		E.db["movers"]["AlertFrameMover"] = "TOP,ElvUIParent,TOP,0,-120"
		E.db["movers"]["DebuffsMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-157,-137"
		E.db["movers"]["MinimapMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-4"
		E.db["movers"]["TalkingHeadFrameMover"] = "TOP,ElvUIParent,TOP,0,-50"
		E.db["movers"]["SquareMinimapButtonBarMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-185"
	end
	
	E:UpdateAll(true)
end

local function MaUISetupAddons()
	--AddonSknins
	if IsAddOnLoaded('AddOnSkins') then
		-- reset the embeds in case of Skada/Recount swap
		E.private['addonskins']['EmbedSystem'] = nil
		E.private['addonskins']['EmbedSystemDual'] = nil
		E.private['addonskins']['EmbedBelowTop'] = nil
		E.private['addonskins']['TransparentEmbed'] = nil
		E.private['addonskins']['RecountBackdrop'] = false
		E.private['addonskins']['EmbedMain'] = nil
		E.private['addonskins']['EmbedLeft'] = nil
		E.private['addonskins']['EmbedRight'] = nil
		
		-- if IsAddOnLoaded('Recount') then
			-- E.private['addonskins']['EmbedMain'] = 'Recount'
			-- E.private['addonskins']['EmbedSystem'] = true
			-- E.private['addonskins']['EmbedSystemDual'] = false
			-- E.private['addonskins']['RecountBackdrop'] = false
			-- E.private['addonskins']['EmbedBelowTop'] = false
			-- E.private['addonskins']['TransparentEmbed'] = true
		-- end
		
		if IsAddOnLoaded('Skada') then
			E.private['addonskins']['EmbedSystem'] = false
			E.private['addonskins']['EmbedSystemDual'] = true
			E.private['addonskins']['EmbedBelowTop'] = false
			E.private['addonskins']['TransparentEmbed'] = false
			E.private['addonskins']['SkadaBackdrop'] = true
			E.private['addonskins']['EmbedMain'] = 'Skada'
			E.private['addonskins']['EmbedLeft'] = 'Skada'
			E.private['addonskins']['EmbedRight'] = 'Skada'
			E.private['addonskins']["EmbedOoC"] = true
		end
		
		-- if IsAddOnLoaded('DBM-Core') then
			-- E.private['addonskins']['DBMFont'] = 'Bui Prototype'
			-- E.private['addonskins']['DBMFontSize'] = 10
			-- E.private['addonskins']['DBMFontFlag'] = 'OUTLINE'
		-- end
	end
	
	--Skada
	if IsAddOnLoaded('Skada') then
	SkadaDB['profiles']["MaUI"] = {
			["windows"] = {
				{
					["barheight"] = 16,
					["returnaftercombat"] = true,
					["classicons"] = false,
					["barslocked"] = true,
					["background"] = {
						["height"] = 102.999992370605,
					},
					["wipemode"] = "Schaden",
					["spark"] = false,
					["bartexture"] = "MaUI Fer 1",
					["barwidth"] = 196.000061035156,
					["buttons"] = {
						["mode"] = false,
						["menu"] = false,
						["stop"] = false,
					},
					["y"] = 15.0000076293945,
					["x"] = 1496.99993896484,
					["name"] = "Schaden",
					["barfont"] = "PT Sans Narrow",
					["modeincombat"] = "Schaden",
					["mode"] = "Schaden",
					["title"] = {
						["font"] = "PT Sans Narrow",
						["fontsize"] = 10,
						["color"] = {
							["a"] = 0.800000011920929,
							["r"] = 0.101960784313725,
							["g"] = 0.101960784313725,
							["b"] = 0.301960784313726,
						},
						["height"] = 13,
						["texture"] = "MaUI Fer 1",
					},
					["point"] = "TOPRIGHT",
				}, -- [1]
				{
					["titleset"] = true,
					["barheight"] = 16,
					["classicons"] = false,
					["barslocked"] = true,
					["enabletitle"] = true,
					["wipemode"] = "Heilung",
					["set"] = "current",
					["hidden"] = false,
					["y"] = 15.0000076293945,
					["barfont"] = "PT Sans Narrow",
					["name"] = "Heilung",
					["display"] = "bar",
					["barfontflags"] = "",
					["classcolortext"] = false,
					["scale"] = 1,
					["reversegrowth"] = false,
					["returnaftercombat"] = true,
					["roleicons"] = false,
					["barorientation"] = 1,
					["snapto"] = true,
					["mode"] = "Heilung",
					["x"] = 1698.00010681152,
					["point"] = "TOPRIGHT",
					["spark"] = false,
					["bartexture"] = "MaUI Fer 1",
					["barwidth"] = 208.999893188477,
					["barspacing"] = 0,
					["buttons"] = {
						["segment"] = true,
						["menu"] = false,
						["mode"] = false,
						["report"] = true,
						["reset"] = true,
					},
					["title"] = {
						["color"] = {
							["a"] = 0.8,
							["r"] = 0.1,
							["g"] = 0.1,
							["b"] = 0.3,
						},
						["bordertexture"] = "None",
						["font"] = "PT Sans Narrow",
						["borderthickness"] = 2,
						["fontsize"] = 10,
						["fontflags"] = "",
						["height"] = 13,
						["margin"] = 0,
						["texture"] = "MaUI Fer 1",
					},
					["barbgcolor"] = {
						["a"] = 0.6,
						["r"] = 0.3,
						["g"] = 0.3,
						["b"] = 0.3,
					},
					["barcolor"] = {
						["a"] = 1,
						["r"] = 0.3,
						["g"] = 0.3,
						["b"] = 0.8,
					},
					["background"] = {
						["borderthickness"] = 0,
						["color"] = {
							["a"] = 0.2,
							["r"] = 0,
							["g"] = 0,
							["b"] = 0.5,
						},
						["height"] = 102.999992370605,
						["bordertexture"] = "None",
						["margin"] = 0,
						["texture"] = "Solid",
					},
					["classcolorbars"] = true,
					["barfontsize"] = 13,
					["clickthrough"] = false,
					["modeincombat"] = "Heilung",
					["version"] = 1,
				}, -- [2]
			},
		}
		
	Skada.db:SetProfile("MaUI")
	end
		
	-- DBM
	-- if IsAddOnLoaded('DBM-Core') then
		-- print(BUI.Title..format(L['- %s profile successfully created!'], dbmName))
		-- DBM:CreateProfile('BenikUI')
		
		-- -- Warnings
		-- DBM_AllSavedOptions["BenikUI"]["WarningFont"] = "Interface\\AddOns\\ElvUI_BenikUI\\media\\fonts\\PROTOTYPE.TTF"
		-- DBM_AllSavedOptions["BenikUI"]["SpecialWarningFont"] = "Interface\\AddOns\\ElvUI_BenikUI\\media\\fonts\\PROTOTYPE.TTF"
		-- DBM_AllSavedOptions["BenikUI"]["SpecialWarningFontShadow"] = true
		-- DBM_AllSavedOptions["BenikUI"]["SpecialWarningFontStyle"] = "NONE"
		
		-- -- Bars
		-- DBT_AllPersistentOptions["BenikUI"]["DBM"]["Texture"] = "Interface\\AddOns\\ElvUI_BenikUI\\media\\textures\\Flat.tga"
		-- DBT_AllPersistentOptions["BenikUI"]["DBM"]["Font"] = "Interface\\AddOns\\ElvUI_BenikUI\\media\\fonts\\PROTOTYPE.TTF"
		-- DBT_AllPersistentOptions["BenikUI"]["DBM"]["Scale"] = 1
		-- DBT_AllPersistentOptions["BenikUI"]["DBM"]["FontSize"] = 12
		-- DBT_AllPersistentOptions["BenikUI"]["DBM"]["HugeScale"] = 1
		
		-- DBM:ApplyProfile('BenikUI')
	-- end
	
	--xCT
	if IsAddOnLoaded('xCT+') then
		xCTSavedDB['profiles']["MaUI"] = {
			["showStartupText"] = false,
			["blizzardFCT"] = {
				["floatingCombatTextCombatDamage"] = true,
				["floatingCombatTextCombatLogPeriodicSpells"] = true,
				["floatingCombatTextDamageReduction"] = true,
				["floatingCombatTextCombatHealing"] = true,
			},
			["frames"] = {
				["general"] = {
					["enabledFrame"] = false,
					["fontOutline"] = "2OUTLINE",
					["iconsEnabled"] = false,
					["Height"] = 150,
					["font"] = "PT Sans Narrow",
					["Width"] = 500,
					["Y"] = 270,
					["X"] = 0,
					["insertText"] = "top",
				},
				["power"] = {
					["enabledFrame"] = false,
				},
				["class"] = {
					["enabledFrame"] = false,
				},
				["outgoing"] = {
					["Y"] = -120,
					["fontSize"] = 14,
					["fontOutline"] = "2OUTLINE",
					["Height"] = 200,
					["font"] = "PT Sans Narrow",
					["X"] = 360,
					["Width"] = 150,
				},
				["critical"] = {
					["Y"] = 80,
					["fontSize"] = 16,
					["fontOutline"] = "5THICKOUTLINE",
					["Height"] = 150,
					["font"] = "MaUI Kait",
					["X"] = 360,
					["Width"] = 150,
				},
				["procs"] = {
					["enabledFrame"] = false,
				},
				["loot"] = {
					["Y"] = -229,
					["fontSize"] = 18,
					["fontOutline"] = "2OUTLINE",
					["Height"] = 138,
					["font"] = "PT Sans Narrow",
					["insertText"] = "bottom",
					["Width"] = 500,
				},
				["healing"] = {
					["fontSize"] = 14,
					["Width"] = 150,
					["Y"] = -80,
					["X"] = -360,
					["fontOutline"] = "2OUTLINE",
					["Height"] = 150,
					["font"] = "PT Sans Narrow",
					["insertText"] = "top",
				},
				["damage"] = {
					["Y"] = 80,
					["fontSize"] = 14,
					["fontOutline"] = "2OUTLINE",
					["Height"] = 150,
					["font"] = "PT Sans Narrow",
					["X"] = -360,
					["Width"] = 150,
				},
			},
			["dbVersion"] = "4.2.3",
		}		
		xCT_Plus.db:SetProfile("MaUI")
		else
			E:Print(L["The AddOn xCT is not enabled. Profile not created. Use the |cffffff00MaUI|r profile."])
		end
		
	E:UpdateAll(true)
end

local function InstallComplete()
	E.private.install_complete = E.version
	E.db.MaUI.installed = true

	ReloadUI()
end

local function ResetAll()
	InstallNextButton:Disable()
	InstallPrevButton:Disable()
	InstallOption1Button:Hide()
	InstallOption1Button:SetScript("OnClick", nil)
	InstallOption1Button:SetText("")
	InstallOption2Button:Hide()
	InstallOption2Button:SetScript('OnClick', nil)
	InstallOption2Button:SetText('')
	InstallOption3Button:Hide()
	InstallOption3Button:SetScript('OnClick', nil)
	InstallOption3Button:SetText('')
	InstallOption4Button:Hide()
	InstallOption4Button:SetScript('OnClick', nil)
	InstallOption4Button:SetText('')
	MaUIInstallFrame.SubTitle:SetText("")
	MaUIInstallFrame.Desc1:SetText("")
	MaUIInstallFrame.Desc2:SetText("")
	MaUIInstallFrame.Desc3:SetText("")
	MaUIInstallFrame:Size(550, 400)
end

local function SetPage(PageNum)
	CURRENT_PAGE = PageNum
	ResetAll()
	InstallStatus.anim.progress:SetChange(PageNum)
	InstallStatus.anim.progress:Play()
	InstallStatus.text:SetText(CURRENT_PAGE.." / "..MAX_PAGE)

	local r, g, b = E:ColorGradient(CURRENT_PAGE / MAX_PAGE, 1, 0, 0, 1, 1, 0, 0, 1, 0)
	MaUIInstallFrame.Status:SetStatusBarColor(r, g, b)
	local f = MaUIInstallFrame

	if PageNum == MAX_PAGE then
		InstallNextButton:Disable()
	else
		InstallNextButton:Enable()
	end

	if PageNum == 1 then
		InstallPrevButton:Disable()
	else
		InstallPrevButton:Enable()
	end

	if PageNum == 1 then
		f.SubTitle:SetFormattedText(L["Welcome to MaUI version %s!"]:gsub("ElvUI", E.UIName), E.version)
		f.Desc1:SetText(L["This install process will help you learn some of the features in ElvUI has to offer and also prepare your user interface for usage."]:gsub("ElvUI", E.UIName))
		f.Desc2:SetText(L["The in-game configuration menu can be accesses by typing the /ec command or by clicking the 'C' button on the minimap. Press the button below if you wish to skip the installation process."])
		f.Desc3:SetText(L["Please press the continue button to go onto the next step."])

		InstallOption1Button:Show()
		InstallOption1Button:SetScript("OnClick", InstallComplete)
		InstallOption1Button:SetText(L["Skip Process"])
	elseif PageNum == 2 then
		f.SubTitle:SetText(L["Chat"])
		f.Desc1:SetText(L["This part of the installation process sets up your World of Warcraft default options it is recommended you should do this step for everything to behave properly."])
		f.Desc2:SetText(L["Please click the button below to setup your Chat."])
		f.Desc3:SetText(L["Importance: |cff07D400High|r"])
		InstallOption1Button:Show()
		InstallOption1Button:SetScript("OnClick", MaUISetupChat)
		InstallOption1Button:SetText(L["Setup Chat"])
	elseif PageNum == 3 then
		f.SubTitle:SetText(L["Actionbars"])
		f.Desc1:SetText(L["This part of the installation process sets up your Actionbars, positions and colors."])
		f.Desc2:SetText(L["The chat windows function the same as Blizzard standard chat windows, you can right click the tabs and drag them around, rename, etc. Please click the button below to setup your chat windows."])
		f.Desc3:SetText(L["Importance: |cffD3CF00Medium|r"])
		InstallOption1Button:Show()
		InstallOption1Button:SetScript("OnClick", MaUISetupActionbars)
		InstallOption1Button:SetText(L["Setup Actionbars"])
	elseif PageNum == 4 then
		f.SubTitle:SetText(L["Layout"])
		f.Desc1:SetText(L["This part of the installation process sets up your chat windows names, positions and colors."])
		f.Desc2:SetText(L["The chat windows function the same as Blizzard standard chat windows, you can right click the tabs and drag them around, rename, etc. Please click the button below to setup your chat windows."])
		f.Desc3:SetText(L["Importance: |cffD3CF00Medium|r"])
		InstallOption1Button:Show()
		InstallOption1Button:SetScript("OnClick", MaUISetupLayout)
		InstallOption1Button:SetText(L["Setup Layout"])
	elseif PageNum == 5 then
		f.SubTitle:SetText(L["Addons"])
		f.Desc1:SetText(L["This part of the installation process sets up your chat windows names, positions and colors."])
		f.Desc2:SetText(L["The chat windows function the same as Blizzard standard chat windows, you can right click the tabs and drag them around, rename, etc. Please click the button below to setup your chat windows."])
		f.Desc3:SetText(L["Importance: |cffD3CF00Medium|r"])
		InstallOption1Button:Show()
		InstallOption1Button:SetScript("OnClick", MaUISetupAddons)
		InstallOption1Button:SetText(L["Setup Addons"])
	elseif PageNum == 6 then
		f.SubTitle:SetText(L["Installation Complete"])
		f.Desc1:SetText(L["You are now finished with the installation process. If you are in need of technical support please visit us at http://www.tukui.org."])
		f.Desc2:SetText(L["Please click the button below so you can setup variables and ReloadUI."])
		InstallOption1Button:Show()
		InstallOption1Button:SetScript("OnClick", InstallComplete)
		InstallOption1Button:SetText(L["Finished"])
		MaUIInstallFrame:Size(550, 350)
	end
end

local function NextPage()
	if CURRENT_PAGE ~= MAX_PAGE then
		CURRENT_PAGE = CURRENT_PAGE + 1
		SetPage(CURRENT_PAGE)
	end
end

local function PreviousPage()
	if CURRENT_PAGE ~= 1 then
		CURRENT_PAGE = CURRENT_PAGE - 1
		SetPage(CURRENT_PAGE)
	end
end

--Install UI
function M:SetupMaUI()
	if not InstallStepComplete then
		local imsg = CreateFrame("Frame", "InstallStepComplete", E.UIParent)
		imsg:Size(418, 72)
		imsg:Point("TOP", 0, -190)
		imsg:Hide()
		imsg:SetScript('OnShow', function(self)
			if self.message then
				PlaySoundFile([[Sound\Interface\LevelUp.wav]])
				self.text:SetText(self.message)
				UIFrameFadeOut(self, 3.5, 1, 0)
				E:Delay(4, function() self:Hide() end)
				self.message = nil
			else
				self:Hide()
			end
		end)

		imsg.firstShow = false

		imsg.bg = imsg:CreateTexture(nil, 'BACKGROUND')
		imsg.bg:SetTexture([[Interface\LevelUp\LevelUpTex]])
		imsg.bg:Point('BOTTOM')
		imsg.bg:Size(326, 103)
		imsg.bg:SetTexCoord(0.00195313, 0.63867188, 0.03710938, 0.23828125)
		imsg.bg:SetVertexColor(1, 1, 1, 0.6)

		imsg.lineTop = imsg:CreateTexture(nil, 'BACKGROUND')
		imsg.lineTop:SetDrawLayer('BACKGROUND', 2)
		imsg.lineTop:SetTexture([[Interface\LevelUp\LevelUpTex]])
		imsg.lineTop:Point("TOP")
		imsg.lineTop:Size(418, 7)
		imsg.lineTop:SetTexCoord(0.00195313, 0.81835938, 0.01953125, 0.03320313)

		imsg.lineBottom = imsg:CreateTexture(nil, 'BACKGROUND')
		imsg.lineBottom:SetDrawLayer('BACKGROUND', 2)
		imsg.lineBottom:SetTexture([[Interface\LevelUp\LevelUpTex]])
		imsg.lineBottom:Point("BOTTOM")
		imsg.lineBottom:Size(418, 7)
		imsg.lineBottom:SetTexCoord(0.00195313, 0.81835938, 0.01953125, 0.03320313)

		imsg.text = imsg:CreateFontString(nil, 'ARTWORK', 'GameFont_Gigantic')
		imsg.text:Point("BOTTOM", 0, 12)
		imsg.text:SetTextColor(1, 0.82, 0)
		imsg.text:SetJustifyH("CENTER")
	end

	--Create Frame
	if not MaUIInstallFrame then
		local f = CreateFrame("Button", "MaUIInstallFrame", E.UIParent)
		f.SetPage = SetPage
		f:Size(550, 400)
		f:SetTemplate("Transparent")
		f:Point("CENTER")
		f:SetFrameStrata('TOOLTIP')

		f.Title = f:CreateFontString(nil, 'OVERLAY')
		f.Title:FontTemplate(nil, 17, nil)
		f.Title:Point("TOP", 0, -5)
		f.Title:SetText(L["ElvUI Installation"]:gsub("ElvUI", E.UIName))

		f.Next = CreateFrame("Button", "InstallNextButton", f, "UIPanelButtonTemplate")
		f.Next:StripTextures()
		f.Next:SetTemplate("Default", true)
		f.Next:Size(110, 25)
		f.Next:Point("BOTTOMRIGHT", -5, 5)
		f.Next:SetText(CONTINUE)
		f.Next:Disable()
		f.Next:SetScript("OnClick", NextPage)
		E.Skins:HandleButton(f.Next, true)

		f.Prev = CreateFrame("Button", "InstallPrevButton", f, "UIPanelButtonTemplate")
		f.Prev:StripTextures()
		f.Prev:SetTemplate("Default", true)
		f.Prev:Size(110, 25)
		f.Prev:Point("BOTTOMLEFT", 5, 5)
		f.Prev:SetText(PREVIOUS)
		f.Prev:Disable()
		f.Prev:SetScript("OnClick", PreviousPage)
		E.Skins:HandleButton(f.Prev, true)

		f.Status = CreateFrame("StatusBar", "InstallStatus", f)
		f.Status:SetFrameLevel(f.Status:GetFrameLevel() + 2)
		f.Status:CreateBackdrop("Default")
		f.Status:SetStatusBarTexture(E["media"].normTex)
		E:RegisterStatusBar(f.Status)
		f.Status:SetStatusBarColor(1, 0, 0)
		f.Status:SetMinMaxValues(0, MAX_PAGE)
		f.Status:Point("TOPLEFT", f.Prev, "TOPRIGHT", 6, -2)
		f.Status:Point("BOTTOMRIGHT", f.Next, "BOTTOMLEFT", -6, 2)
		-- Setup StatusBar Animation
		f.Status.anim = CreateAnimationGroup(f.Status)
		f.Status.anim.progress = f.Status.anim:CreateAnimation("Progress")
		f.Status.anim.progress:SetSmoothing("Out")
		f.Status.anim.progress:SetDuration(.3)

		f.Status.text = f.Status:CreateFontString(nil, 'OVERLAY')
		f.Status.text:FontTemplate()
		f.Status.text:Point("CENTER")
		f.Status.text:SetText(CURRENT_PAGE.." / "..MAX_PAGE)

		f.Option1 = CreateFrame("Button", "InstallOption1Button", f, "UIPanelButtonTemplate")
		f.Option1:StripTextures()
		f.Option1:Size(160, 30)
		f.Option1:Point("BOTTOM", 0, 45)
		f.Option1:SetText("")
		f.Option1:Hide()
		E.Skins:HandleButton(f.Option1, true)

		f.Option2 = CreateFrame("Button", "InstallOption2Button", f, "UIPanelButtonTemplate")
		f.Option2:StripTextures()
		f.Option2:Size(110, 30)
		f.Option2:Point('BOTTOMLEFT', f, 'BOTTOM', 4, 45)
		f.Option2:SetText("")
		f.Option2:Hide()
		f.Option2:SetScript('OnShow', function() f.Option1:Width(110); f.Option1:ClearAllPoints(); f.Option1:Point('BOTTOMRIGHT', f, 'BOTTOM', -4, 45) end)
		f.Option2:SetScript('OnHide', function() f.Option1:Width(160); f.Option1:ClearAllPoints(); f.Option1:Point("BOTTOM", 0, 45) end)
		E.Skins:HandleButton(f.Option2, true)

		f.Option3 = CreateFrame("Button", "InstallOption3Button", f, "UIPanelButtonTemplate")
		f.Option3:StripTextures()
		f.Option3:Size(100, 30)
		f.Option3:Point('LEFT', f.Option2, 'RIGHT', 4, 0)
		f.Option3:SetText("")
		f.Option3:Hide()
		f.Option3:SetScript('OnShow', function() f.Option1:Width(100); f.Option1:ClearAllPoints(); f.Option1:Point('RIGHT', f.Option2, 'LEFT', -4, 0); f.Option2:Width(100); f.Option2:ClearAllPoints(); f.Option2:Point('BOTTOM', f, 'BOTTOM', 0, 45)  end)
		f.Option3:SetScript('OnHide', function() f.Option1:Width(160); f.Option1:ClearAllPoints(); f.Option1:Point("BOTTOM", 0, 45); f.Option2:Width(110); f.Option2:ClearAllPoints(); f.Option2:Point('BOTTOMLEFT', f, 'BOTTOM', 4, 45) end)
		E.Skins:HandleButton(f.Option3, true)

		f.Option4 = CreateFrame("Button", "InstallOption4Button", f, "UIPanelButtonTemplate")
		f.Option4:StripTextures()
		f.Option4:Size(100, 30)
		f.Option4:Point('LEFT', f.Option3, 'RIGHT', 4, 0)
		f.Option4:SetText("")
		f.Option4:Hide()
		f.Option4:SetScript('OnShow', function()
			f.Option1:Width(100)
			f.Option2:Width(100)

			f.Option1:ClearAllPoints();
			f.Option1:Point('RIGHT', f.Option2, 'LEFT', -4, 0);
			f.Option2:ClearAllPoints();
			f.Option2:Point('BOTTOMRIGHT', f, 'BOTTOM', -4, 45)
		end)
		f.Option4:SetScript('OnHide', function() f.Option1:Width(160); f.Option1:ClearAllPoints(); f.Option1:Point("BOTTOM", 0, 45); f.Option2:Width(110); f.Option2:ClearAllPoints(); f.Option2:Point('BOTTOMLEFT', f, 'BOTTOM', 4, 45) end)
		E.Skins:HandleButton(f.Option4, true)

		f.SubTitle = f:CreateFontString(nil, 'OVERLAY')
		f.SubTitle:FontTemplate(nil, 15, nil)
		f.SubTitle:Point("TOP", 0, -40)

		f.Desc1 = f:CreateFontString(nil, 'OVERLAY')
		f.Desc1:FontTemplate()
		f.Desc1:Point("TOPLEFT", 20, -75)
		f.Desc1:Width(f:GetWidth() - 40)

		f.Desc2 = f:CreateFontString(nil, 'OVERLAY')
		f.Desc2:FontTemplate()
		f.Desc2:Point("TOPLEFT", 20, -125)
		f.Desc2:Width(f:GetWidth() - 40)

		f.Desc3 = f:CreateFontString(nil, 'OVERLAY')
		f.Desc3:FontTemplate()
		f.Desc3:Point("TOPLEFT", 20, -175)
		f.Desc3:Width(f:GetWidth() - 40)

		local close = CreateFrame("Button", "InstallCloseButton", f, "UIPanelCloseButton")
		close:Point("TOPRIGHT", f, "TOPRIGHT")
		close:SetScript("OnClick", function()
			f:Hide()
		end)
		E.Skins:HandleCloseButton(close)

		f.tutorialImage = f:CreateTexture('InstallTutorialImage', 'OVERLAY')
		f.tutorialImage:Size(256, 128)
		f.tutorialImage:SetTexture('Interface\\AddOns\\ElvUI\\media\\textures\\logo.tga')
		f.tutorialImage:Point('BOTTOM', 0, 70)
	end

	MaUIInstallFrame:Show()
	NextPage()
end